@@ -67,6 +67,7 @@ static void cb_anthy_bt_delete(GtkButton *button, AnthyViewWordPane *pane) {
     GtkWidget *dialog;
     GList *selected_data;
     word *data;
+    int ret;
 
     selected_data = wordlist_view_get_selected_data_list(WORDLIST_VIEW(pane->wordlist_anthy));
     if(selected_data == NULL)
@@ -76,16 +77,25 @@ static void cb_anthy_bt_delete(GtkButton *button, AnthyViewWordPane *pane) {
 
 /* TODO: Must handle multiple selection */
 
-    delete_anthy_priv_dic(utf8_to_eucjp(data->phon),
-			  utf8_to_eucjp(data->desc),
-			  utf8_to_eucjp(data->cclass_code));
+    ret = delete_anthy_priv_dic(utf8_to_eucjp(data->phon),
+				utf8_to_eucjp(data->desc),
+				utf8_to_eucjp(data->cclass_code));
 /* End of TODO */
 
-    dialog = gtk_message_dialog_new(NULL,
-				    GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
-				    GTK_BUTTONS_CLOSE,
-				    _("Sorry, not implemented."
-				      "Just deleting from list"));
+    if(!ret) {
+	dialog = gtk_message_dialog_new(NULL,
+					GTK_DIALOG_MODAL,
+					GTK_MESSAGE_INFO,
+					GTK_BUTTONS_CLOSE,
+					_("Word deletion succeded."));
+    } else {
+	dialog = gtk_message_dialog_new(NULL,
+					GTK_DIALOG_MODAL,
+					GTK_MESSAGE_ERROR,
+					GTK_BUTTONS_CLOSE,
+					_("Word deletion failed."));
+    }
+
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
 
