@@ -427,10 +427,12 @@ static void cclass_verb_dialog(CannaAddWordPane *pane) {
 
     narrow_size = sizeof(verb_code) / sizeof(verb_code[0]);
     for(i = 0; i < narrow_size; i++) {
-	gtk_list_store_append(store, &iter);
-	gtk_list_store_set(store, &iter,
-			   COLUMN_CCLASS_CODE, eucjp_to_utf8(verb_code[i].desc),
-			   -1);
+	if(verb_code[i].type & SUPPORT_CANNA) {
+	    gtk_list_store_append(store, &iter);
+	    gtk_list_store_set(store, &iter,
+			       COLUMN_CCLASS_CODE, eucjp_to_utf8(verb_code[i].desc),
+			       -1);
+	}
     }
 
     result = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -720,11 +722,13 @@ static void cclass_adjective_dialog(CannaAddWordPane *pane) {
 
     narrow_size = sizeof(adjective_code) / sizeof(adjective_code[0]);
     for(i = 0; i < narrow_size; i++) {
-	gtk_list_store_append(store, &iter);
-	gtk_list_store_set(store, &iter,
-			   COLUMN_CCLASS_CODE,
-			   eucjp_to_utf8(adjective_code[i].desc),
-			   -1);
+	if(adjective_code[i].type & SUPPORT_CANNA) {
+	    gtk_list_store_append(store, &iter);
+	    gtk_list_store_set(store, &iter,
+			       COLUMN_CCLASS_CODE,
+			       eucjp_to_utf8(adjective_code[i].desc),
+			       -1);
+	}
     }
 
     result = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -989,11 +993,13 @@ static void cclass_etc_dialog(CannaAddWordPane *pane) {
 
     narrow_size = sizeof(etc_code) / sizeof(etc_code[0]);
     for(i = 0; i < narrow_size; i++) {
-	gtk_list_store_append(store, &iter);
-	gtk_list_store_set(store, &iter,
-			   COLUMN_CCLASS_CODE,
-			   eucjp_to_utf8(etc_code[i].desc),
-			   -1);
+	if(etc_code[i].type & SUPPORT_CANNA) {
+	    gtk_list_store_append(store, &iter);
+	    gtk_list_store_set(store, &iter,
+			       COLUMN_CCLASS_CODE,
+			       eucjp_to_utf8(etc_code[i].desc),
+			       -1);
+	}
     }
 
     result = gtk_dialog_run(GTK_DIALOG(dialog));
