@@ -22,12 +22,6 @@ typedef enum {
     ANTHY_FUKUSHI_TO_SETUZOKU         = 1 << 3
 } touroku_fukushi_attr_list;
 
-typedef struct _category_code {
-    char *code;
-    char *description;
-    int   flag;
-} category_code;
-
 /* Prototypes */
 int   anthydic_init  (void);
 int   anthydic_close (void);
@@ -39,4 +33,5 @@ int   delete_anthy_priv_dic         (char *, char *, char *);
 char *find_meishi_code_from_flag    (const int);
 char *find_fukushi_code_from_flag   (const int);
 char *find_hinshi_name_from_code    (const char*);
+
 #endif /* __ANTHY_H__ */
